PCB Environment: NavMesh Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
NavMesh Class Reference

## Public Member Functions
| NavMesh (const PCBoard &)
void | update (uint z)
void | setPointSize (float s)
void | setColor (Color)
void | setAlpha (float a)
void | draw (const Camera &)
void | setVisualizeAStar (bool b)

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/NavMesh.hpp